@@ -16,6 +16,7 @@ from toscaparser.common import exception
 from toscaparser import functions
 from toscaparser.tests.base import TestCase
 from toscaparser.tosca_template import ToscaTemplate
+from toscaparser.utils.gettextutils import _
 
 
 class IntrinsicFunctionsTest(TestCase):
@@ -66,13 +67,13 @@ class IntrinsicFunctionsTest(TestCase):
         self.assertEqual('my_db_user', result)
 
     def test_unknown_capability_property(self):
-        err = self.assertRaises(
+        self.assertRaises(exception.ValidationError, self._load_template,
+                          'functions/test_unknown_capability_property.yaml')
+        exception.ExceptionCollector.assertExceptionMessage(
             KeyError,
-            self._load_template,
-            'functions/test_unknown_capability_property.yaml')
-        self.assertIn("'unknown'", six.text_type(err))
-        self.assertIn("'database_endpoint'", six.text_type(err))
-        self.assertIn("'database'", six.text_type(err))
+            _('\'Property "unknown" was not found in capability '
+              '"database_endpoint" of node template "database" referenced '
+              'from node template "database".\''))
 
     def test_get_input_in_properties(self):
         mysql_dbms = self._get_node('mysql_dbms')
@@ -85,15 +86,27 @@ class IntrinsicFunctionsTest(TestCase):
         self.assertListEqual(expected_inputs, [])
 
     def test_get_input_validation(self):
-        self.assertRaises(exception.UnknownInputError,
-                          self._load_template,
-                          'functions/test_unknown_input_in_property.yaml')
-        self.assertRaises(exception.UnknownInputError,
-                          self._load_template,
-                          'functions/test_unknown_input_in_interface.yaml')
-        self.assertRaises(ValueError,
-                          self._load_template,
-                          'functions/test_invalid_function_signature.yaml')
+        self.assertRaises(
+            exception.ValidationError, self._load_template,
+            'functions/test_unknown_input_in_property.yaml')
+        exception.ExceptionCollector.assertExceptionMessage(
+            exception.UnknownInputError,
+            _('Unknown input "objectstore_name".'))
+
+        self.assertRaises(
+            exception.ValidationError, self._load_template,
+            'functions/test_unknown_input_in_interface.yaml')
+        exception.ExceptionCollector.assertExceptionMessage(
+            exception.UnknownInputError,
+            _('Unknown input "image_id".'))
+
+        self.assertRaises(
+            exception.ValidationError, self._load_template,
+            'functions/test_invalid_function_signature.yaml')
+        exception.ExceptionCollector.assertExceptionMessage(
+            ValueError,
+            _('Expected one argument for function "get_input" but received '
+              '"[\'cpus\', \'cpus\']".'))
 
     def test_get_input_default_value_result(self):
         mysql_dbms = self._get_node('mysql_dbms')
@@ -122,7 +135,8 @@ class GetAttributeTest(TestCase):
                          website_url_output.value.attribute_name)
 
     def test_get_attribute_invalid_args(self):
-        expected_msg = 'Expected arguments: node-template-name, attribute-name'
+        expected_msg = _('Expected arguments: "node-template-name", '
+                         '"attribute-name"')
         err = self.assertRaises(ValueError,
                                 functions.get_function, None, None,
                                 {'get_attribute': []})
@@ -137,19 +151,21 @@ class GetAttributeTest(TestCase):
         self.assertIn(expected_msg, six.text_type(err))
 
     def test_get_attribute_unknown_node_template_name(self):
-        err = self.assertRaises(
-            KeyError,
-            self._load_template,
+        self.assertRaises(
+            exception.ValidationError, self._load_template,
             'functions/test_get_attribute_unknown_node_template_name.yaml')
-        self.assertIn('unknown_node_template', six.text_type(err))
+        exception.ExceptionCollector.assertExceptionMessage(
+            KeyError,
+            _('\'Node template "unknown_node_template" was not found.\''))
 
     def test_get_attribute_unknown_attribute(self):
-        err = self.assertRaises(
-            KeyError,
-            self._load_template,
+        self.assertRaises(
+            exception.ValidationError, self._load_template,
             'functions/test_get_attribute_unknown_attribute_name.yaml')
-        self.assertIn('unknown_attribute', six.text_type(err))
-        self.assertIn('server', six.text_type(err))
+        exception.ExceptionCollector.assertExceptionMessage(
+            KeyError,
+            _('\'Attribute "unknown_attribute" was not found in node template '
+              '"server".\''))
 
     def test_get_attribute_host_keyword(self):
         tpl = self._load_template(
@@ -169,21 +185,20 @@ class GetAttributeTest(TestCase):
         assert_get_attribute_host_functionality('database')
 
     def test_get_attribute_host_not_found(self):
-        err = self.assertRaises(
-            ValueError,
-            self._load_template,
+        self.assertRaises(
+            exception.ValidationError, self._load_template,
             'functions/test_get_attribute_host_not_found.yaml')
-        self.assertIn(
-            "get_attribute HOST keyword is used in 'server' node template but "
-            "tosca.relationships.HostedOn was not found in relationship chain",
-            six.text_type(err))
+        exception.ExceptionCollector.assertExceptionMessage(
+            ValueError,
+            _('"get_attribute: [ HOST, ... ]" was used in node template '
+              '"server" but "tosca.relationships.HostedOn" was not found in '
+              'the relationship chain.'))
 
     def test_get_attribute_illegal_host_in_outputs(self):
-        err = self.assertRaises(
-            ValueError,
-            self._load_template,
+        self.assertRaises(
+            exception.ValidationError, self._load_template,
             'functions/test_get_attribute_illegal_host_in_outputs.yaml')
-        self.assertIn(
-            "get_attribute HOST keyword is not allowed within the outputs "
-            "section of the TOSCA template",
-            six.text_type(err))
+        exception.ExceptionCollector.assertExceptionMessage(
+            ValueError,
+            _('"get_attribute: [ HOST, ... ]" is not allowed in "outputs" '
+              'section of the TOSCA template.'))
